@@ -8,9 +8,12 @@ void LabelEncoderTest::basic_test() {
   int max_length = 2000000;
 //  srand(222); // NOLINT(cert-msc51-cpp)
   std::vector<std::string> sample_chars = {
-      "a", "b",
-      "c", "d", "e", "f", "g", "h", "i", "j", "k", "l", "m", "n", "o", "p", "q", "r", "s", "t", "u", "v", "w", "x", "y", "z",
-      "A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V", "W", "X", "Y", "Z",
+      "a", "b", "c", "d", "e", "f", "g", "h", "i",
+      "j", "k", "l", "m", "n", "o", "p", "q", "r",
+      "s", "t", "u", "v", "w", "x", "y", "z", "A",
+      "B", "C", "D", "E", "F", "G", "H", "I", "J",
+      "K", "L", "M", "N", "O", "P", "Q", "R", "S",
+      "T", "U", "V", "W", "X", "Y", "Z",
   };
   u_long char_count = sample_chars.size();
   std::vector<std::string> sample_words = std::vector<std::string>();
