@@ -1,6 +1,7 @@
 from ctypes import (
     Structure,
-    c_int, c_char_p,
+    c_int,
+    c_char_p,
 )
 
 from lightning_fast.c_structs.uthash import UT_hash_handle
