@@ -16,6 +16,12 @@ class LoggerUtil(object):
         log_file_name: Optional[str] = None,
         logger_level: Optional[int] = None,
     ) -> logging.Logger:
+        """
+        :param log_path: log文件位置
+        :param log_file_name: log文件名
+        :param logger_level: log级别
+        :return: Logger
+        """
         formatter = logging.Formatter(
             "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
         )
